# Opteryx

Opteryx-Core is fork of [Opteryx](https://github.com/mabel-dev/opteryx) with a reduced API and configuration surface.

Install:
```bash
pip install opteryx-core
```

Docs: https://opteryx.dev/  •  Source: https://github.com/mabel-dev/opteryx-core  •  License: Apache-2.0
